@@ -328,6 +328,11 @@ void DragState::onDelegateDragPositionOverFavouritesChanged()
         m_favouritesInsertBetweenTimer->stop();
     }
 
+    // ignore this event if the favourites area is full already
+    if (FavouritesModel::self()->isFull()) {
+        return;
+    }
+
     // ignore widget drop delegates (since they can't be placed in the favourites)
     if (m_dropDelegate && m_dropDelegate->type() == FolioDelegate::Widget) {
         return;
@@ -528,9 +533,7 @@ void DragState::onDelegateDropped()
 
     // delete empty pages at the end if they exist
     // (it can be created if user drags app to new page, but doesn't place it there)
-    while (PageListModel::self()->isLastPageEmpty() && PageListModel::self()->rowCount() > 1) {
-        PageListModel::self()->removePage(PageListModel::self()->rowCount() - 1);
-    }
+    PageListModel::self()->deleteEmptyPagesAtEnd();
 
     // clear ghost position if there is one
     FavouritesModel::self()->deleteGhostEntry();
